@@ -32,7 +32,7 @@ from session_function import ViewSessionInfo
 from CertificateClass import CertClass
 
 from pid_information import client_list_pid
-from more import icon_visible, client_del_sid, show_msg
+from more import icon_visible, client_del_sid, show_msg, get_icon
 
 DEBUG_LEVEL = 0
 
@@ -415,6 +415,9 @@ class MainWgt(qt.QMainWindow):
     def show_close_messagebox(self):
         list_pid = client_list_pid(self.ClientObj.client)
 
+        if not list_pid:
+            return qt.QMessageBox.Yes
+
         msgBox = qt.QMessageBox(self)
         msgBox.setWindowTitle(_('Closing session'))
         msgBox.setText(_("Close this session") + ' ' + _('with %s?') \
@@ -438,7 +441,7 @@ class MainWgt(qt.QMainWindow):
         msgBox.button(msgBox.Cancel).setText(_('Cancel'))
 
         msgBox.setDefaultButton(qt.QMessageBox.Cancel)
-        msgBox.setWindowIcon(qt.QIcon.fromTheme("application-exit"))
+        msgBox.setWindowIcon(get_icon("application-exit"))
         reply = msgBox.exec_()
         return reply
 
