@@ -17,7 +17,7 @@
 from calculate.consolegui import qt
 from more import ButtonMenu, icon_visible, LabelWordWrap, get_sid, show_msg, \
                  ClientServiceThread, show_question, get_view_params, _print, \
-    get_system_rgb
+    get_system_rgb, dpivalue
 
 
 class StepLabel(qt.QLabel):
@@ -35,7 +35,7 @@ class StepLabel(qt.QLabel):
                            "background-color: %s;}"%bg)
         self.setContentsMargins(26,0,26,0)
         self.adjustSize()
-        self.setFixedHeight(self.height() + 13)
+        self.setFixedHeight(dpivalue(self.height() + 18))
 
     def mousePressEvent(self, event):
         self.clicked.emit()
